==> haskell-hls-brittany-plugin-1.0.0.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-brittany-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-brittany-plugin
version:              1.0.0.1
visibility:           public
id:                   hls-brittany-plugin-1.0.0.1-JH4nXr7fEF81ksZ9zVxJtL
key:                  hls-brittany-plugin-1.0.0.1-JH4nXr7fEF81ksZ9zVxJtL
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Brittany code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e336634e4ed732d54d3bcfc129a0307f
exposed:              True
exposed-modules:      Ide.Plugin.Brittany
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hls-brittany-plugin-1.0.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hls-brittany-plugin-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/hls-brittany-plugin-1.0.0.1

hs-libraries:         HShls-brittany-plugin-1.0.0.1-JH4nXr7fEF81ksZ9zVxJtL
depends:
    base-4.14.2.0 brittany-0.13.1.2-8gplgpHcE5QA4x1R6FyP0y
    filepath-1.4.2.1 ghc-8.10.5 ghc-boot-th-8.10.5
    ghcide-1.2.0.2-D490cHkH8Gd1nUNUpLXRiV
    hls-plugin-api-1.1.0.0-D7TB4PKlhC688kStLXBKPe
    lens-5.0.1-35rFO49duny9UmEBJRCnDB
    lsp-types-1.2.0.0-15hZ8oIlnBmBUgfRzgi2dp text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-brittany-plugin/html/hls-brittany-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-brittany-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-brittany-plugin-1.0.0.1-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-brittany-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-brittany-plugin
version:              1.0.0.1
visibility:           public
id:                   hls-brittany-plugin-1.0.0.1-K32ibDShwQ6CTz4wJ1eXcr
key:                  hls-brittany-plugin-1.0.0.1-K32ibDShwQ6CTz4wJ1eXcr
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Brittany code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  fed11e9981ccff488f01a283fc473f04
exposed:              True
exposed-modules:      Ide.Plugin.Brittany
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hls-brittany-plugin-1.0.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hls-brittany-plugin-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/hls-brittany-plugin-1.0.0.1

hs-libraries:         HShls-brittany-plugin-1.0.0.1-K32ibDShwQ6CTz4wJ1eXcr
depends:
    base-4.14.2.0 brittany-0.13.1.2-8gplgpHcE5QA4x1R6FyP0y
    filepath-1.4.2.1 ghc-8.10.5 ghc-boot-th-8.10.5
    ghcide-1.4.0.1-DM2bbRuSxePBXNMy140RZQ
    hls-plugin-api-1.1.0.2-3kA08zfkoJ93tQ43WlvAJ0
    lens-5.0.1-35rFO49duny9UmEBJRCnDB
    lsp-types-1.2.0.0-It0slYT1Cr57i9oVdLKGll text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-brittany-plugin/html/hls-brittany-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-brittany-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
